@@ -1,6 +1,6 @@
-extern crate meterproxy;
+extern crate meter_proxy;
 
-use meterproxy::proxy::async::AsyncMeterProxy;
+use meter_proxy::proxy::async::AsyncMeterProxy;
 use std::thread;
 use std::time::Duration;
 
